@@ -178,11 +178,7 @@ struct _ClutterActor
  *   and natural heights of an actor for a given width; it is used by
  *   clutter_actor_get_preferred_height()
  * @allocate: virtual function, used when settings the coordinates of an
- *   actor; it is used by clutter_actor_allocate(); it must chain up to
- *   the parent's implementation
- * @apply_transform: virtual function, used when applying the transformations
- *   to an actor before painting it or when transforming coordinates or
- *   the allocation; it must chain up to the parent's implementation
+ *   actor; it is used by clutter_actor_allocate()
  * @parent_set: signal class handler for the #ClutterActor::parent-set
  * @destroy: signal class handler for #ClutterActor::destroy
  * @pick: virtual function, used to draw an outline of the actor with
@@ -242,11 +238,6 @@ struct _ClutterActorClass
   void (* allocate)             (ClutterActor           *actor,
                                  const ClutterActorBox  *box,
                                  ClutterAllocationFlags  flags);
-
-  /* transformations */
-  void (* apply_transform)      (ClutterActor           *actor,
-                                 CoglMatrix             *matrix);
-
   /* event signals */
   gboolean (* event)                (ClutterActor         *actor,
                                      ClutterEvent         *event);
@@ -293,6 +284,8 @@ void                  clutter_actor_unrealize                 (ClutterActor
 void                  clutter_actor_map                       (ClutterActor          *self);
 void                  clutter_actor_unmap                     (ClutterActor          *self);
 void                  clutter_actor_paint                     (ClutterActor          *self);
+void                  clutter_actor_pick                      (ClutterActor          *self,
+                                                               const ClutterColor    *color);
 void                  clutter_actor_queue_redraw              (ClutterActor          *self);
 void                  clutter_actor_queue_relayout            (ClutterActor          *self);
 void                  clutter_actor_destroy                   (ClutterActor          *self);
@@ -322,6 +315,11 @@ void                  clutter_actor_allocate_available_size   (ClutterActor
                                                                gfloat                 available_width,
                                                                gfloat                 available_height,
                                                                ClutterAllocationFlags flags);
+void                  clutter_actor_get_allocation_coords     (ClutterActor          *self,
+                                                               gint                  *x_1,
+                                                               gint                  *y_1,
+                                                               gint                  *x_2,
+                                                               gint                  *y_2);
 void                  clutter_actor_get_allocation_box        (ClutterActor          *self,
                                                                ClutterActorBox       *box);
 void                  clutter_actor_get_allocation_geometry   (ClutterActor          *self,
@@ -329,6 +327,7 @@ void                  clutter_actor_get_allocation_geometry   (ClutterActor
 void                  clutter_actor_get_allocation_vertices   (ClutterActor          *self,
 							       ClutterActor          *ancestor,
                                                                ClutterVertex          verts[4]);
+
 void                  clutter_actor_set_geometry              (ClutterActor          *self,
                                                                const ClutterGeometry *geometry);
 void                  clutter_actor_get_geometry              (ClutterActor          *self,
@@ -517,9 +516,6 @@ PangoContext *clutter_actor_create_pango_context      (ClutterActor        *self
 PangoLayout * clutter_actor_create_pango_layout       (ClutterActor        *self,
                                                        const gchar         *text);
 
-void clutter_actor_get_transformation_matrix          (ClutterActor        *self,
-                                                       CoglMatrix          *matrix);
-
 G_END_DECLS
 
-#endif /* __CLUTTER_ACTOR_H__ */
+#endif /* _HAVE_CLUTTER_ACTOR_H */
