@@ -198,8 +198,4 @@
 
 #define clutter_timeline_get_progressx  clutter_timeline_get_progressx_DEPRECATED_BY_clutter_timeline_get_progress
 
-#define clutter_actor_pick      clutter_actor_pick_DEPRECATED_BY_clutter_actor_paint
-
-#define clutter_actor_get_allocation_coords     clutter_actor_get_allocation_coords_DEPRECATED_BY_clutter_actor_get_allocation_box
-
 #endif /* CLUTTER_DEPRECATED_H */
