@@ -94,8 +94,7 @@ static const GDebugKey clutter_debug_keys[] = {
   { "shader", CLUTTER_DEBUG_SHADER },
   { "multistage", CLUTTER_DEBUG_MULTISTAGE },
   { "animation", CLUTTER_DEBUG_ANIMATION },
-  { "layout", CLUTTER_DEBUG_LAYOUT },
-  { "nop-picking", CLUTTER_DEBUG_NOP_PICKING }
+  { "layout", CLUTTER_DEBUG_LAYOUT }
 };
 #endif /* CLUTTER_ENABLE_DEBUG */
 
@@ -153,15 +152,12 @@ _clutter_stage_maybe_relayout (ClutterActor *stage)
 void
 _clutter_stage_maybe_setup_viewport (ClutterStage *stage)
 {
-  if ((CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_ACTOR_SYNC_MATRICES) &&
-      !(CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_STAGE_IN_RESIZE))
+  if (CLUTTER_PRIVATE_FLAGS (stage) & CLUTTER_ACTOR_SYNC_MATRICES)
     {
       ClutterPerspective perspective;
       gfloat width, height;
 
-      clutter_actor_get_preferred_size (CLUTTER_ACTOR (stage),
-                                        NULL, NULL,
-                                        &width, &height);
+      clutter_actor_get_size (CLUTTER_ACTOR (stage), &width, &height);
       clutter_stage_get_perspective (stage, &perspective);
 
       CLUTTER_NOTE (PAINT,
@@ -379,9 +375,6 @@ _clutter_do_pick (ClutterStage   *stage,
   guint32             id;
   GLboolean           dither_was_on;
 
-  if (clutter_debug_flags & CLUTTER_DEBUG_NOP_PICKING)
-    return CLUTTER_ACTOR (stage);
-
   context = _clutter_context_get_default ();
 
   _clutter_backend_ensure_context (context->backend, stage);
@@ -412,9 +405,6 @@ _clutter_do_pick (ClutterStage   *stage,
   /* Calls should work under both GL and GLES, note GLES needs RGBA */
   glGetIntegerv(GL_VIEWPORT, viewport);
 
-  /* Make sure Cogl flushes any batched geometry to the GPU driver */
-  cogl_flush ();
-
   /* Read the color of the screen co-ords pixel */
   glReadPixels (x, viewport[3] - y -1, 1, 1, GL_RGBA, GL_UNSIGNED_BYTE, pixel);
 
