@@ -26,10 +26,13 @@
 #ifndef __COGL_DEFINES_H__
 #define __COGL_DEFINES_H__
 
+#include <glib.h>
 #include <GL/gl.h>
 
 G_BEGIN_DECLS
 
+#define  1
+
 /* ClearBufferMask */
 #define CGL_DEPTH_BUFFER_BIT GL_DEPTH_BUFFER_BIT
 #define CGL_STENCIL_BUFFER_BIT GL_STENCIL_BUFFER_BIT
@@ -162,7 +165,7 @@ G_BEGIN_DECLS
 #define CGL_STENCIL_PASS_DEPTH_PASS GL_STENCIL_PASS_DEPTH_PASS
 #define CGL_STENCIL_REF GL_STENCIL_REF
 #define CGL_STENCIL_WRITEMASK GL_STENCIL_WRITEMASK
-#ifdef HAVE_COGL_GLES2
+#ifdef COGL_HAS_GLES2
 #define CGL_MATRIX_MODE	0x0BA0 /* bad style but works for now */
 #else
 #define CGL_MATRIX_MODE GL_MATRIX_MODE
@@ -194,7 +197,7 @@ G_BEGIN_DECLS
 #define CGL_MAX_VIEWPORT_DIMS GL_MAX_VIEWPORT_DIMS
 #define CGL_MAX_ELEMENTS_VERTICES GL_MAX_ELEMENTS_VERTICES
 #define CGL_MAX_ELEMENTS_INDICES GL_MAX_ELEMENTS_INDICES
-#ifdef HAVE_COGL_GLES2
+#ifdef COGL_HAS_GLES2
 #define CGL_MAX_COMBINED_TEXTURE_IMAGE_UNITS GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS
 #else
 #define CGL_MAX_COMBINED_TEXTURE_IMAGE_UNITS GL_MAX_TEXTURE_UNITS
@@ -429,10 +432,6 @@ G_BEGIN_DECLS
 #define CGL_WEIGHT_ARRAY_BUFFER_BINDING_OES GL_WEIGHT_ARRAY_BUFFER_BINDING_OES
 #define CGL_TEXTURE_CROP_RECT_OES GL_TEXTURE_CROP_RECT_OES
 
-typedef GLenum COGLenum;
-typedef GLint  COGLint;
-typedef GLuint COGLuint;
-
 /* extras */
 
 /* YUV textures also unsupported */
@@ -440,18 +439,6 @@ typedef GLuint COGLuint;
 #define CGL_UNSIGNED_SHORT_8_8_REV_MESA 0
 #define CGL_UNSIGNED_SHORT_8_8_MESA 0
 
-#ifdef GL_FRAGMENT_SHADER
-#define CGL_FRAGMENT_SHADER GL_FRAGMENT_SHADER
-#else
-#define CGL_FRAGMENT_SHADER 0
-#endif
-
-#ifdef GL_VERTEX_SHADER
-#define CGL_VERTEX_SHADER GL_VERTEX_SHADER
-#else
-#define CGL_VERTEX_SHADER 0
-#endif
-
 #if defined(GL_OBJECT_COMPILE_STATUS)
 #define CGL_OBJECT_COMPILE_STATUS GL_OBJECT_COMPILE_STATUS
 #elif defined(GL_COMPILE_STATUS)
