@@ -301,6 +301,7 @@ cogl_vertex_buffer_draw (CoglHandle       handle,
  * CoglIndicesType:
  * @COGL_INDICES_TYPE_UNSIGNED_BYTE: Your indices are unsigned bytes
  * @COGL_INDICES_TYPE_UNSIGNED_SHORT: Your indices are unsigned shorts
+ * @COGL_INDICES_TYPE_UNSIGNED_INT: You indices are unsigned integers
  *
  * You should aim to use the smallest data type that gives you enough
  * range, since it reduces the size of your index array and can help
@@ -310,6 +311,7 @@ typedef enum _CoglIndicesType
 {
   COGL_INDICES_TYPE_UNSIGNED_BYTE,
   COGL_INDICES_TYPE_UNSIGNED_SHORT,
+  COGL_INDICES_TYPE_UNSIGNED_INT
 } CoglIndicesType;
 
 /**
@@ -332,17 +334,6 @@ cogl_vertex_buffer_indices_new (CoglIndicesType  indices_type,
                                 const void      *indices_array,
                                 int              indices_len);
 
-/**
- * cogl_vertex_buffer_indices_get_type:
- * @handle: An indices handle
- *
- * Queries back the data type used for the given indices
- *
- * Returns: The CoglIndicesType used
- */
-CoglIndicesType
-cogl_vertex_buffer_indices_get_type (CoglHandle indices);
-
 /**
  * cogl_vertex_buffer_delete_indices:
  * @handle: A vertex buffer handle
