@@ -1,13 +1,12 @@
 /*
- * Clutter COGL
+ * Cogl
  *
- * A basic GL/GLES Abstraction/Utility Layer
+ * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Authored By Matthew Allum  <mallum@openedhand.com>
- *
- * Copyright (C) 2007 OpenedHand
+ * Copyright (C) 2008,2009 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
+
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
@@ -41,10 +40,12 @@
 #include <cogl/cogl-material.h>
 #include <cogl/cogl-path.h>
 #include <cogl/cogl-shader.h>
+#include <cogl/cogl-bitmap.h>
 #include <cogl/cogl-texture.h>
 #include <cogl/cogl-types.h>
 #include <cogl/cogl-debug.h>
 #include <cogl/cogl-deprecated.h>
+#include <cogl/cogl-enum-types.h>
 
 G_BEGIN_DECLS
 
@@ -55,22 +56,6 @@ G_BEGIN_DECLS
  * General utility functions for COGL.
  */
 
-/* Context manipulation */
-
-/**
- * cogl_create_context:
- *
- * FIXME
- */
-gboolean        cogl_create_context           (void);
-
-/**
- * cogl_destroy_context:
- *
- * FIXME
- */
-void            cogl_destroy_context          (void);
-
 /**
  * cogl_get_option_group:
  *
@@ -187,7 +172,30 @@ void            cogl_frustum                  (float        left,
                                                float        z_far);
 
 /**
- * cogl_setup_viewport:
+ * cogl_ortho:
+ * @left: The coordinate for the left clipping plane
+ * @right: The coordinate for the right clipping plane
+ * @bottom: The coordinate for the bottom clipping plane
+ * @top: The coordinate for the top clipping plane
+ * @near: The coordinate for the near clipping plane (may be negative if
+ *        the plane is behind the viewer)
+ * @far: The coordinate for the far clipping plane (may be negative if
+ *       the plane is behind the viewer)
+ *
+ * Replaces the current projection matrix with a parallel projection
+ * matrix.
+ *
+ * Since: 1.0
+ */
+void            cogl_ortho                    (float left,
+                                               float right,
+                                               float bottom,
+                                               float top,
+                                               float near,
+                                               float far);
+
+/*
+ * _cogl_setup_viewport:
  * @width: Width of the viewport
  * @height: Height of the viewport
  * @fovy: Field of view angle in degrees
@@ -201,9 +209,11 @@ void            cogl_frustum                  (float        left,
  * with one that has a viewing angle of @fovy along the y-axis and a
  * view scaled according to @aspect along the x-axis. The view is
  * clipped according to @z_near and @z_far on the z-axis.
+ *
+ * This function is used only by Clutter.
  */
-void            cogl_setup_viewport           (guint               width,
-                                               guint               height,
+void            _cogl_setup_viewport          (guint        width,
+                                               guint        height,
                                                float        fovy,
                                                float        aspect,
                                                float        z_near,
@@ -288,6 +298,14 @@ void            cogl_rotate                   (float                angle,
  */
 void            cogl_get_modelview_matrix     (CoglMatrix *matrix);
 
+/**
+ * cogl_set_modelview_matrix:
+ * @matrix: pointer to a CoglMatrix to set as the new model-view matrix
+ *
+ * Loads matrix as the new model-view matrix.
+ */
+void            cogl_set_modelview_matrix     (CoglMatrix *matrix);
+
 /**
  * cogl_get_projection_matrix:
  * @matrix: pointer to a CoglMatrix to recieve the matrix
@@ -296,6 +314,14 @@ void            cogl_get_modelview_matrix     (CoglMatrix *matrix);
  */
 void            cogl_get_projection_matrix    (CoglMatrix *matrix);
 
+/**
+ * cogl_set_projection_matrix:
+ * @matrix: pointer to a CoglMatrix to set as the new projection matrix
+ *
+ * Loads matrix as the new projection matrix.
+ */
+void            cogl_set_projection_matrix    (CoglMatrix *matrix);
+
 /**
  * cogl_get_viewport:
  * @v: pointer to a 4 element array of #float<!-- -->s to
@@ -308,7 +334,7 @@ void            cogl_get_projection_matrix    (CoglMatrix *matrix);
 void            cogl_get_viewport             (float        v[4]);
 
 /**
- * cogl_enable_depth_test:
+ * cogl_set_depth_test_enabled:
  * @setting: %TRUE to enable depth testing or %FALSE to disable.
  *
  * Sets whether depth testing is enabled. If it is disabled then the
@@ -317,19 +343,38 @@ void            cogl_get_viewport             (float        v[4]);
  * clutter_actor_lower(), otherwise it will also take into account the
  * actor's depth. Depth testing is disabled by default.
  */
-void            cogl_enable_depth_test        (gboolean            setting);
+void            cogl_set_depth_test_enabled   (gboolean setting);
 
 /**
- * cogl_enable_backface_culling:
+ * cogl_get_depth_test_enable:
+ *
+ * Queries if depth testing has been enabled via cogl_set_depth_test_enable()
+ *
+ * Returns: TRUE if depth testing is enabled else FALSE
+ */
+gboolean        cogl_get_depth_test_enabled   (void);
+
+/**
+ * cogl_set_backface_culling_enabled:
  * @setting: %TRUE to enable backface culling or %FALSE to disable.
  *
  * Sets whether textures positioned so that their backface is showing
  * should be hidden. This can be used to efficiently draw two-sided
- * textures or fully closed cubes without enabling depth testing. Only
- * calls to cogl_texture_rectangle() and cogl_texture_polygon() are
- * affected. Backface culling is disabled by default.
+ * textures or fully closed cubes without enabling depth testing. This
+ * only affects calls to the cogl_rectangle* family of functions and
+ * cogl_vertex_buffer_draw*. Backface culling is disabled by default.
  */
-void            cogl_enable_backface_culling  (gboolean            setting);
+void            cogl_set_backface_culling_enabled (gboolean setting);
+
+/**
+ * cogl_get_backface_culling_enabled:
+ *
+ * Queries if backface culling has been enabled via
+ * cogl_set_backface_culling_enabled()
+ *
+ * Returns: TRUE if backface culling is enabled else FALSE
+ */
+gboolean        cogl_get_backface_culling_enabled (void);
 
 /**
  * cogl_set_fog:
@@ -341,13 +386,22 @@ void            cogl_enable_backface_culling  (gboolean            setting);
  * @z_near: Position along z-axis where no fogging should be applied
  * @z_far: Position along z-axes where full fogging should be applied
  *
- * Enables fogging. Fogging causes vertices that are further away from
- * the eye to be rendered with a different color. The color is determined
- * according to the chosen fog mode; at it's simplest the color is
- * linearly interpolated so that vertices at @z_near are drawn fully
- * with their original color and vertices at @z_far are drawn fully
- * with @fog_color. Fogging will remain enabled until you call
- * cogl_disable_fog().
+ * Enables fogging. Fogging causes vertices that are further away from the eye
+ * to be rendered with a different color. The color is determined according to
+ * the chosen fog mode; at it's simplest the color is linearly interpolated so
+ * that vertices at @z_near are drawn fully with their original color and
+ * vertices at @z_far are drawn fully with @fog_color. Fogging will remain
+ * enabled until you call cogl_disable_fog().
+ *
+ * Note: The fogging functions only work correctly when primitives use
+ *       unmultiplied alpha colors. By default Cogl will premultiply textures
+ *       and cogl_set_source_color will premultiply colors, so unless you
+ *       explicitly load your textures requesting an unmultiplied
+ *       internal_format and use cogl_material_set_color you can only use
+ *       fogging with fully opaque primitives.
+ *
+ *       We can look to improve this in the future when we can depend on
+ *       fragment shaders.
  */
 void            cogl_set_fog                  (const CoglColor *fog_color,
                                                CoglFogMode      mode,
@@ -363,14 +417,33 @@ void            cogl_set_fog                  (const CoglColor *fog_color,
  */
 void            cogl_disable_fog              (void);
 
+/**
+ * CoglBufferBit:
+ * @COGL_BUFFER_BIT_COLOR: Selects the primary color buffer
+ * @COGL_BUFFER_BIT_DEPTH: Selects the depth buffer
+ * @COGL_BUFFER_BIT_STENCIL: Selects the stencil buffer
+ *
+ * Types of auxiliary buffers
+ *
+ * Since: 1.0
+ */
+typedef enum {
+  COGL_BUFFER_BIT_COLOR   = 1L<<0,
+  COGL_BUFFER_BIT_DEPTH   = 1L<<1,
+  COGL_BUFFER_BIT_STENCIL = 1L<<2
+} CoglBufferBit;
+
 /**
  * cogl_clear:
  * @color: Background color to clear to
+ * @buffers: A mask of #CoglBufferBit<!-- -->'s identifying which auxiliary
+ *   buffers to clear
  *
- * Clears the color buffer to @color. The depth buffer and stencil
- * buffers are also cleared.
+ * Clears all the auxiliary buffers identified in the @buffers mask, and if
+ * that includes the color buffer then the specified @color is used.
  */
-void            cogl_clear                    (const CoglColor *color);
+void            cogl_clear                    (const CoglColor *color,
+                                               gulong           buffers);
 
 /**
  * cogl_set_source:
@@ -391,8 +464,13 @@ void            cogl_set_source               (CoglHandle material);
  * cogl_set_source_color:
  * @color: a #CoglColor
  *
- * Sets the source color using normalized values for each component.
- * This color will be used for any subsequent drawing operation.
+ * This is a convenience function for creating a solid fill source material
+ * from the given color. This color will be used for any subsequent drawing
+ * operation.
+ *
+ * The color will be premultiplied by Cogl, so the color should be
+ * non-premultiplied. For example: use (1.0, 0.0, 0.0, 0.5) for
+ * semi-transparent red.
  *
  * See also cogl_set_source_color4ub() and cogl_set_source_color4f()
  * if you already have the color components.
@@ -475,6 +553,27 @@ void            cogl_set_source_texture       (CoglHandle texture_handle);
  * intersected with the previous region.
  */
 
+/**
+ * cogl_clip_push_window_rect:
+ * @x_offset: left edge of the clip rectangle in window coordinates
+ * @y_offset: top edge of the clip rectangle in window coordinates
+ * @width: width of the clip rectangle
+ * @height: height of the clip rectangle
+ *
+ * Specifies a rectangular clipping area for all subsequent drawing
+ * operations. Any drawing commands that extend outside the rectangle
+ * will be clipped so that only the portion inside the rectangle will
+ * be displayed. The rectangle dimensions are not transformed by the
+ * current model-view matrix.
+ *
+ * The rectangle is intersected with the current clip region. To undo
+ * the effect of this function, call cogl_clip_pop().
+ */
+void            cogl_clip_push_window_rect    (float x_offset,
+                                               float y_offset,
+                                               float width,
+                                               float height);
+
 /**
  * cogl_clip_push:
  * @x_offset: left edge of the clip rectangle
@@ -564,6 +663,52 @@ void            cogl_clip_stack_save          (void);
 void            cogl_clip_stack_restore       (void);
 
 /**
+ * cogl_set_draw_buffer:
+ * @target: A #CoglBufferTarget that specifies what kind of draw buffer you
+ *          are setting as the render target.
+ * @offscreen: If you are setting a draw buffer of type COGL_OFFSCREEN_BUFFER
+ *             then this is a CoglHandle for the offscreen buffer.
+ *
+ * This redirects all subsequent drawing to the specified draw buffer. This
+ * can either be an offscreen buffer created with
+ * cogl_offscreen_new_to_texture () or you can revert to your original
+ * on screen window buffer.
+ */
+void            cogl_set_draw_buffer          (CoglBufferTarget    target,
+                                               CoglHandle          offscreen);
+
+/**
+ * cogl_push_draw_buffer:
+ *
+ * Save cogl_set_draw_buffer() state.
+ */
+void            cogl_push_draw_buffer         (void);
+
+/**
+ * cogl_pop_draw_buffer:
+ *
+ * Restore cogl_set_draw_buffer() state.
+ */
+void            cogl_pop_draw_buffer          (void);
+
+
+/*
+ * Internal API available only to Clutter.
+ *
+ * These are typically only to deal with the poor seperation of
+ * responsabilities that currently exists between Clutter and Cogl.
+ * Eventually a lot of the backend code currently in Clutter will
+ * move down into Cogl and these functions will be removed.
+ */
+
+void            _cogl_destroy_context          (void);
+
+/* XXX: Removed before we release Clutter 1.0 since the implementation
+ * wasn't complete, and so we assume no one is using this yet. Util we
+ * have some one with a good usecase, we can't pretend to support breaking
+ * out into raw OpenGL. */
+#if 0
+/*
  * cogl_flush_gl_state:
  * @flags: flags controlling what is flushed; currently unused, pass in 0
  *
@@ -577,6 +722,7 @@ void            cogl_clip_stack_restore       (void);
  * Since: 1.0
  */
 void            cogl_flush_gl_state         (int      flags);
+#endif
 
 /* private */
 void            _cogl_set_indirect_context  (gboolean indirect);
