@@ -137,7 +137,6 @@
 #include "cogl-vertex-buffer-private.h"
 #include "cogl-texture-private.h"
 #include "cogl-material-private.h"
-#include "cogl-primitives.h"
 
 #define PAD_FOR_ALIGNMENT(VAR, TYPE_SIZE) \
   (VAR = TYPE_SIZE + ((VAR - 1) & ~(TYPE_SIZE - 1)))
@@ -1501,10 +1500,9 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
   gulong       enable_flags = 0;
   guint        max_texcoord_attrib_unit = 0;
   const GList *layers;
-  guint32      fallback_layers = 0;
-  guint32      disable_layers = ~0;
+  guint32      fallback_mask = 0;
+  guint32      disable_mask = ~0;
   int          i;
-  CoglMaterialFlushOptions options;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
@@ -1575,7 +1573,7 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
 				     pointer));
               if (attribute->texture_unit > max_texcoord_attrib_unit)
                 max_texcoord_attrib_unit = attribute->texture_unit;
-              disable_layers &= ~(1 << attribute->texture_unit);
+              disable_mask &= ~(1 << attribute->texture_unit);
 	      break;
 	    case COGL_VERTEX_BUFFER_ATTRIB_FLAG_VERTEX_ARRAY:
 	      enable_flags |= COGL_ENABLE_VERTEX_ARRAY;
@@ -1618,14 +1616,8 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
     {
       CoglHandle layer = (CoglHandle)tmp->data;
       CoglHandle tex_handle = cogl_material_layer_get_texture (layer);
-      CoglTexture *texture;
-
-      /* invalid textures will be handled correctly in
-       * _cogl_material_flush_layers_gl_state */
-      if (tex_handle == COGL_INVALID_HANDLE)
-        continue;
-
-      texture = _cogl_texture_pointer_from_handle (tex_handle);
+      CoglTexture *texture =
+        _cogl_texture_pointer_from_handle (tex_handle);
 
       if (cogl_texture_is_sliced (tex_handle)
           || _cogl_texture_span_has_waste (texture, 0, 0))
@@ -1646,24 +1638,17 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
            * vertices once for each layer, each time with a fiddled texture
            * matrix.
            */
-          fallback_layers |= (1 << i);
+          fallback_mask |= (1 << i);
         }
     }
 
-  for (i = max_texcoord_attrib_unit + 1; i < ctx->n_texcoord_arrays_enabled; i++)
-    {
-      GE (glClientActiveTexture (GL_TEXTURE0 + i));
-      GE (glDisableClientState (GL_TEXTURE_COORD_ARRAY));
-    }
-  ctx->n_texcoord_arrays_enabled = max_texcoord_attrib_unit + 1;
+  _cogl_material_flush_gl_state (ctx->source_material,
+                                 COGL_MATERIAL_FLUSH_FALLBACK_MASK,
+                                 fallback_mask,
+                                 COGL_MATERIAL_FLUSH_DISABLE_MASK,
+                                 disable_mask,
+                                 NULL);
 
-  options.flags =
-    COGL_MATERIAL_FLUSH_FALLBACK_MASK |
-    COGL_MATERIAL_FLUSH_DISABLE_MASK;
-  options.fallback_layers = fallback_layers;
-  options.disable_layers = disable_layers;
-
-  _cogl_material_flush_gl_state (ctx->source_material, &options);
   enable_flags |= _cogl_material_get_cogl_enable_flags (ctx->source_material);
 
   if (ctx->enable_backface_culling)
@@ -1745,9 +1730,6 @@ cogl_vertex_buffer_draw (CoglHandle       handle,
   if (!cogl_is_vertex_buffer (handle))
     return;
 
-  _cogl_journal_flush ();
-  cogl_clip_ensure ();
-
   buffer = _cogl_vertex_buffer_pointer_from_handle (handle);
 
   cogl_clip_ensure ();
@@ -1820,27 +1802,6 @@ cogl_vertex_buffer_indices_new (CoglIndicesType  indices_type,
   return _cogl_vertex_buffer_indices_handle_new (indices);
 }
 
-CoglIndicesType
-cogl_vertex_buffer_indices_get_type (CoglHandle indices_handle)
-{
-  CoglVertexBufferIndices *indices = NULL;
-
-  if (!cogl_is_vertex_buffer_indices (indices_handle))
-    return COGL_INDICES_TYPE_UNSIGNED_SHORT;
-
-  indices = _cogl_vertex_buffer_indices_pointer_from_handle (indices_handle);
-
-  if (indices->type == GL_UNSIGNED_BYTE)
-    return COGL_INDICES_TYPE_UNSIGNED_BYTE;
-  else if (indices->type == GL_UNSIGNED_SHORT)
-    return COGL_INDICES_TYPE_UNSIGNED_SHORT;
-  else
-    {
-      g_critical ("unknown indices type %d", indices->type);
-      return COGL_INDICES_TYPE_UNSIGNED_SHORT;
-    }
-}
-
 void
 _cogl_vertex_buffer_indices_free (CoglVertexBufferIndices *indices)
 {
@@ -1877,9 +1838,6 @@ cogl_vertex_buffer_draw_elements (CoglHandle       handle,
   if (!cogl_is_vertex_buffer (handle))
     return;
 
-  _cogl_journal_flush ();
-  cogl_clip_ensure ();
-
   buffer = _cogl_vertex_buffer_pointer_from_handle (handle);
 
   if (!cogl_is_vertex_buffer_indices (indices_handle))
