@@ -216,9 +216,6 @@ cogl_get_enable ()
 void
 cogl_set_depth_test_enabled (gboolean setting)
 {
-  /* Currently the journal can't track changes to depth state... */
-  _cogl_journal_flush ();
-
   if (setting)
     {
       glEnable (GL_DEPTH_TEST);
@@ -239,9 +236,6 @@ cogl_set_backface_culling_enabled (gboolean setting)
 {
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
-  /* Currently the journal can't track changes to backface culling state... */
-  _cogl_journal_flush ();
-
   ctx->enable_backface_culling = setting;
 }
 
@@ -394,15 +388,9 @@ _cogl_add_stencil_clip (float x_offset,
 			float height,
 			gboolean first)
 {
-  CoglHandle current_source;
-
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
-  _cogl_journal_flush ();
-
-  /* temporarily swap in our special stenciling material */
-  current_source = cogl_handle_ref (ctx->source_material);
-  cogl_set_source (ctx->stencil_material);
+  _cogl_material_flush_gl_state (ctx->stencil_material, NULL);
 
   if (first)
     {
@@ -455,17 +443,9 @@ _cogl_add_stencil_clip (float x_offset,
       _cogl_set_current_matrix (COGL_MATRIX_MODELVIEW);
     }
 
-  /* make sure our rectangles hit the stencil buffer before we restore
-   * the stencil function / operation */
-  _cogl_journal_flush ();
-
   /* Restore the stencil mode */
   GE( glStencilFunc (GL_EQUAL, 0x1, 0x1) );
   GE( glStencilOp (GL_KEEP, GL_KEEP, GL_KEEP) );
-
-  /* restore the original source material */
-  cogl_set_source (current_source);
-  cogl_handle_unref (current_source);
 }
 
 void
@@ -492,19 +472,11 @@ _cogl_disable_clip_planes (void)
   GE( glDisable (GL_CLIP_PLANE0) );
 }
 
-/* XXX: This should be deprecated and Cogl should be left to manage
- * the glViewport automatically when switching draw buffers. */
 void
 cogl_viewport (guint width,
 	       guint height)
 {
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
-
-  COGL_NOTE (MISC, "glViewport(0, 0, %u, %u)", width, height);
   GE( glViewport (0, 0, width, height) );
-
-  ctx->viewport_width = width;
-  ctx->viewport_height = height;
 }
 
 void
@@ -518,7 +490,7 @@ _cogl_setup_viewport (guint width,
   float z_camera;
   CoglMatrix projection_matrix;
 
-  cogl_viewport (width, height);
+  GE( glViewport (0, 0, width, height) );
 
   /* For Ortho projection.
    * _cogl_current_matrix_ortho (0, width, 0,  height, -1, 1);
@@ -582,9 +554,6 @@ cogl_get_features (void)
   if (!ctx->features_cached)
     _cogl_features_init ();
 
-  if (cogl_debug_flags & COGL_DEBUG_DISABLE_VBOS)
-    ctx->feature_flags &= ~COGL_FEATURE_VBOS;
-
   return ctx->feature_flags;
 }
 
@@ -599,18 +568,21 @@ cogl_features_available (CoglFeatureFlags features)
   return (ctx->feature_flags & features) == features;
 }
 
-/* XXX: This function should be deprecated, and replaced with a
- * cogl_draw_buffer_get_size() API instead. We don't support offset
- * viewports, and you can't have floating point viewport sizes. */
 void
 cogl_get_viewport (float v[4])
 {
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  /* FIXME: cogl_get_viewport should return a gint vec */
+#if defined (HAVE_COGL_GLES2) || defined (HAVE_COGL_GLES)
+  GLint viewport[4];
+  int i;
 
-  v[0] = 0;
-  v[1] = 0;
-  v[2] = ctx->viewport_width;
-  v[3] = ctx->viewport_height;
+  glGetIntegerv (GL_VIEWPORT, viewport);
+
+  for (i = 0; i < 4; i++)
+    v[i] = (float)(viewport[i]);
+#else
+  glGetFloatv (GL_VIEWPORT, v);
+#endif
 }
 
 void
@@ -656,9 +628,6 @@ cogl_set_fog (const CoglColor *fog_color,
   GLfloat fogColor[4];
   GLenum gl_mode = GL_LINEAR;
 
-  /* The cogl journal doesn't currently track fog state changes */
-  _cogl_journal_flush ();
-
   fogColor[0] = cogl_color_get_red_float (fog_color);
   fogColor[1] = cogl_color_get_green_float (fog_color);
   fogColor[2] = cogl_color_get_blue_float (fog_color);
@@ -696,9 +665,6 @@ cogl_set_fog (const CoglColor *fog_color,
 void
 cogl_disable_fog (void)
 {
-  /* Currently the journal can't track changes to fog state... */
-  _cogl_journal_flush ();
-
   glDisable (GL_FOG);
 }
 
@@ -710,142 +676,3 @@ cogl_flush_gl_state (int flags)
 }
 #endif
 
-void
-cogl_flush (void)
-{
-  _cogl_journal_flush ();
-}
-
-void
-cogl_read_pixels (int x,
-                  int y,
-                  int width,
-                  int height,
-                  CoglReadPixelsFlags source,
-                  CoglPixelFormat format,
-                  guint8 *pixels)
-{
-  GLint   viewport[4];
-  GLint   viewport_height;
-  int     rowstride = width * 4;
-  guint8  temprow[rowstride];
-
-  g_return_if_fail (format == COGL_PIXEL_FORMAT_RGBA_8888);
-  g_return_if_fail (source == COGL_READ_PIXELS_COLOR_BUFFER);
-
-  glGetIntegerv (GL_VIEWPORT, viewport);
-  viewport_height = viewport[3];
-
-  /* The y co-ordinate should be given in OpenGL's coordinate system
-     so 0 is the bottom row */
-  y = viewport_height - y - height;
-
-  /* Setup the pixel store parameters that may have been changed by
-     Cogl */
-  glPixelStorei (GL_PACK_ALIGNMENT, 4);
-#ifdef HAVE_COGL_GL
-  glPixelStorei (GL_PACK_ROW_LENGTH, 0);
-  glPixelStorei (GL_PACK_SKIP_PIXELS, 0);
-  glPixelStorei (GL_PACK_SKIP_ROWS, 0);
-#endif /* HAVE_COGL_GL */
-
-  /* make sure any batched primitives get emitted to the GL driver before
-   * issuing our read pixels... */
-  cogl_flush ();
-
-  glReadPixels (x, y, width, height, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
-
-  /* TODO: consider using the GL_MESA_pack_invert extension in the future
-   * to avoid this flip... */
-
-  /* vertically flip the buffer in-place */
-  for (y = 0; y < height / 2; y++)
-    {
-      if (y != height - y - 1) /* skip center row */
-        {
-          memcpy (temprow,
-                  pixels + y * rowstride, rowstride);
-          memcpy (pixels + y * rowstride,
-                  pixels + (height - y - 1) * rowstride, rowstride);
-          memcpy (pixels + (height - y - 1) * rowstride,
-                  temprow,
-                  rowstride);
-        }
-    }
-}
-
-void
-cogl_begin_gl (void)
-{
-  CoglMaterialFlushOptions options;
-  gulong enable_flags;
-  int i;
-
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
-
-  if (ctx->in_begin_gl_block)
-    {
-      static gboolean shown = FALSE;
-      if (!shown)
-        g_warning ("You should not nest cogl_begin_gl/cogl_end_gl blocks");
-      shown = TRUE;
-      return;
-    }
-  ctx->in_begin_gl_block = TRUE;
-
-  /* Flush all batched primitives */
-  cogl_flush ();
-
-  /* Flush our clipping state to GL */
-  cogl_clip_ensure ();
-
-  /* Flush any client side matrix state */
-  _cogl_current_matrix_state_flush ();
-
-
-  /* Setup the state for the current material */
-
-  /* We considered flushing a specific, minimal material here to try and
-   * simplify the GL state, but decided to avoid special cases and second
-   * guessing what would be actually helpful.
-   *
-   * A user should instead call cogl_set_source_color4ub() before
-   * cogl_begin_gl() to simplify the state flushed.
-   */
-  options.flags = 0;
-  _cogl_material_flush_gl_state (ctx->source_material, &options);
-
-  /* FIXME: This api is a bit yukky, ideally it will be removed if we
-   * re-work the cogl_enable mechanism */
-  enable_flags |= _cogl_material_get_cogl_enable_flags (ctx->source_material);
-
-  if (ctx->enable_backface_culling)
-    enable_flags |= COGL_ENABLE_BACKFACE_CULLING;
-
-  cogl_enable (enable_flags);
-
-  /* Disable all client texture coordinate arrays */
-  for (i = 0; i < ctx->n_texcoord_arrays_enabled; i++)
-    {
-      GE (glClientActiveTexture (GL_TEXTURE0 + i));
-      GE (glDisableClientState (GL_TEXTURE_COORD_ARRAY));
-    }
-  ctx->n_texcoord_arrays_enabled = 0;
-}
-
-void
-cogl_end_gl (void)
-{
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
-
-  if (!ctx->in_begin_gl_block)
-    {
-      static gboolean shown = FALSE;
-      if (!shown)
-        g_warning ("cogl_end_gl is being called before cogl_begin_gl");
-      shown = TRUE;
-      return;
-    }
-  ctx->in_begin_gl_block = FALSE;
-}
-
