@@ -1,11 +1,9 @@
 /*
- * Clutter COGL
+ * Cogl
  *
- * A basic GL/GLES Abstraction/Utility Layer
+ * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Authored By Matthew Allum  <mallum@openedhand.com>
- *
- * Copyright (C) 2007 OpenedHand
+ * Copyright (C) 2007,2008,2009 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,11 +37,12 @@
 static CoglContext *_context = NULL;
 static gboolean gl_is_indirect = FALSE;
 
-gboolean
+static gboolean
 cogl_create_context ()
 {
   GLubyte default_texture_data[] = { 0xff, 0xff, 0xff, 0x0 };
   gulong  enable_flags = 0;
+  CoglDrawBufferState *draw_buffer;
 
   if (_context != NULL)
     return FALSE;
@@ -62,18 +61,14 @@ cogl_create_context ()
 
   _context->indirect = gl_is_indirect;
 
-  _context->material_handles = NULL;
-  _context->material_layer_handles = NULL;
   _context->default_material = cogl_material_new ();
   _context->source_material = NULL;
 
-  _context->texture_handles = NULL;
   _context->default_gl_texture_2d_tex = COGL_INVALID_HANDLE;
   _context->default_gl_texture_rect_tex = COGL_INVALID_HANDLE;
 
   _context->journal = g_array_new (FALSE, FALSE, sizeof (CoglJournalEntry));
   _context->logged_vertices = g_array_new (FALSE, FALSE, sizeof (GLfloat));
-  _context->static_indices = g_array_new (FALSE, FALSE, sizeof (GLushort));
   _context->polygon_vertices = g_array_new (FALSE, FALSE,
                                             sizeof (CoglTextureGLVertex));
 
@@ -83,14 +78,11 @@ cogl_create_context ()
                                           sizeof (CoglLayerInfo));
   _context->n_texcoord_arrays_enabled = 0;
 
-  _context->fbo_handles = NULL;
-  _context->draw_buffer = COGL_WINDOW_BUFFER;
-
-  _context->shader_handles = NULL;
-
-  _context->program_handles = NULL;
-
-  _context->vertex_buffer_handles = NULL;
+  draw_buffer = g_slice_new0 (CoglDrawBufferState);
+  draw_buffer->target = COGL_WINDOW_BUFFER;
+  draw_buffer->offscreen = COGL_INVALID_HANDLE;
+  _context->draw_buffer_stack =
+    g_slist_prepend (NULL, draw_buffer);
 
   _context->path_nodes = g_array_new (FALSE, FALSE, sizeof (CoglPathNode));
   _context->last_path = 0;
@@ -143,6 +135,9 @@ cogl_create_context ()
   _context->pf_glActiveTexture = NULL;
   _context->pf_glClientActiveTexture = NULL;
 
+  _context->pf_glBlendFuncSeparate = NULL;
+  _context->pf_glBlendEquationSeparate = NULL;
+
   /* Initialise the clip stack */
   _cogl_clip_stack_state_init ();
 
@@ -153,8 +148,7 @@ cogl_create_context ()
   _context->default_gl_texture_2d_tex =
     cogl_texture_new_from_data (1, /* width */
                                 1, /* height */
-                                -1, /* max waste */
-                                COGL_TEXTURE_NONE, /* flags */
+                                COGL_TEXTURE_NO_SLICING,
                                 COGL_PIXEL_FORMAT_RGBA_8888, /* data format */
                                 /* internal format */
                                 COGL_PIXEL_FORMAT_RGBA_8888,
@@ -163,8 +157,7 @@ cogl_create_context ()
   _context->default_gl_texture_rect_tex =
     cogl_texture_new_from_data (1, /* width */
                                 1, /* height */
-                                -1, /* max waste */
-                                COGL_TEXTURE_NONE, /* flags */
+                                COGL_TEXTURE_NO_SLICING,
                                 COGL_PIXEL_FORMAT_RGBA_8888, /* data format */
                                 /* internal format */
                                 COGL_PIXEL_FORMAT_RGBA_8888,
@@ -172,16 +165,20 @@ cogl_create_context ()
                                 default_texture_data);
 
   cogl_set_source (_context->default_material);
-  cogl_material_flush_gl_state (_context->source_material, NULL);
+  _cogl_material_flush_gl_state (_context->source_material, NULL);
   enable_flags =
-    cogl_material_get_cogl_enable_flags (_context->source_material);
+    _cogl_material_get_cogl_enable_flags (_context->source_material);
   cogl_enable (enable_flags);
 
+  _context->quad_indices_byte = COGL_INVALID_HANDLE;
+  _context->quad_indices_short = COGL_INVALID_HANDLE;
+  _context->quad_indices_short_len = 0;
+
   return TRUE;
 }
 
 void
-cogl_destroy_context ()
+_cogl_destroy_context ()
 {
   if (_context == NULL)
     return;
@@ -193,35 +190,29 @@ cogl_destroy_context ()
   if (_context->path_nodes)
     g_array_free (_context->path_nodes, TRUE);
 
-  if (_context->texture_handles)
-    g_array_free (_context->texture_handles, TRUE);
-  if (_context->fbo_handles)
-    g_array_free (_context->fbo_handles, TRUE);
-  if (_context->shader_handles)
-    g_array_free (_context->shader_handles, TRUE);
-  if (_context->program_handles)
-    g_array_free (_context->program_handles, TRUE);
-
   if (_context->default_gl_texture_2d_tex)
-    cogl_texture_unref (_context->default_gl_texture_2d_tex);
+    cogl_handle_unref (_context->default_gl_texture_2d_tex);
   if (_context->default_gl_texture_rect_tex)
-    cogl_texture_unref (_context->default_gl_texture_rect_tex);
+    cogl_handle_unref (_context->default_gl_texture_rect_tex);
 
   if (_context->default_material)
-    cogl_material_unref (_context->default_material);
+    cogl_handle_unref (_context->default_material);
 
   if (_context->journal)
     g_array_free (_context->journal, TRUE);
   if (_context->logged_vertices)
     g_array_free (_context->logged_vertices, TRUE);
 
-  if (_context->static_indices)
-    g_array_free (_context->static_indices, TRUE);
   if (_context->polygon_vertices)
     g_array_free (_context->polygon_vertices, TRUE);
   if (_context->current_layers)
     g_array_free (_context->current_layers, TRUE);
 
+  if (_context->quad_indices_byte)
+    cogl_handle_unref (_context->quad_indices_byte);
+  if (_context->quad_indices_short)
+    cogl_handle_unref (_context->quad_indices_short);
+
   g_free (_context);
 }
 
