@@ -1,11 +1,9 @@
 /*
- * Clutter COGL
+ * Cogl
  *
- * A basic GL/GLES Abstraction/Utility Layer
+ * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Authored By Matthew Allum  <mallum@openedhand.com>
- *
- * Copyright (C) 2007 OpenedHand
+ * Copyright (C) 2007,2008,2009 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,6 +38,12 @@ typedef struct
   GLubyte c[4];
 } CoglTextureGLVertex;
 
+typedef struct
+{
+  CoglBufferTarget target;
+  CoglHandle offscreen;
+} CoglDrawBufferState;
+
 typedef struct
 {
   /* Features cache */
@@ -62,13 +66,10 @@ typedef struct
   float            inverse_projection[16];
 
   /* Materials */
-  GArray           *material_handles;
-  GArray           *material_layer_handles;
   CoglHandle        default_material;
   CoglHandle	    source_material;
 
   /* Textures */
-  GArray	   *texture_handles;
   CoglHandle        default_gl_texture_2d_tex;
   CoglHandle        default_gl_texture_rect_tex;
   CoglHandle        texture_download_material;
@@ -79,7 +80,6 @@ typedef struct
    * can batch things together. */
   GArray           *journal;
   GArray           *logged_vertices;
-  GArray           *static_indices;
   GArray           *polygon_vertices;
 
   /* Some simple caching, to minimize state changes... */
@@ -89,21 +89,11 @@ typedef struct
   guint             n_texcoord_arrays_enabled;
 
   /* Framebuffer objects */
-  GArray           *fbo_handles;
-  CoglBufferTarget  draw_buffer;
-
-  /* Shaders */
-  GArray           *shader_handles;
-
-  /* Programs */
-  GArray           *program_handles;
+  GSList           *draw_buffer_stack;
 
   /* Clip stack */
   CoglClipStackState clip;
 
-  /* Vertex buffers */
-  GArray           *vertex_buffer_handles;
-
   /* Primitives */
   floatVec2         path_start;
   floatVec2         path_pen;
@@ -113,6 +103,12 @@ typedef struct
   floatVec2         path_nodes_max;
   CoglHandle        stencil_material;
 
+  /* Pre-generated VBOs containing indices to generate GL_TRIANGLES
+     out of a vertex array of quads */
+  CoglHandle        quad_indices_byte;
+  guint             quad_indices_short_len;
+  CoglHandle        quad_indices_short;
+
 #ifdef HAVE_COGL_GLES2
   CoglGles2Wrapper     gles2;
 
@@ -120,7 +116,6 @@ typedef struct
      supported */
   GLint                viewport_store[4];
 #endif
-
 } CoglContext;
 
 CoglContext *
