@@ -43,7 +43,7 @@
 
 #include <X11/Xatom.h>
 
-#ifdef USE_XINPUT
+#ifdef HAVE_XINPUT
 #include <X11/extensions/XInput.h>
 #endif
 
@@ -263,7 +263,7 @@ set_user_time (ClutterBackendX11 *backend_x11,
     }
 }
 
-#if 0 /* See XInput keyboard comment below USE_XINPUT */
+#if 0 /* See XInput keyboard comment below HAVE_XINPUT */
 static void
 convert_xdevicekey_to_xkey (XDeviceKeyEvent *xkev, XEvent *xevent)
 {
@@ -282,7 +282,7 @@ convert_xdevicekey_to_xkey (XDeviceKeyEvent *xkev, XEvent *xevent)
   xevent->xkey.keycode = xkev->keycode;
   xevent->xkey.same_screen = xkev->same_screen;
 }
-#endif /* USE_XINPUT */
+#endif /* HAVE_XINPUT */
 
 static void
 translate_key_event (ClutterBackend   *backend,
@@ -479,15 +479,16 @@ event_translate (ClutterBackend *backend,
                         xevent->xconfigure.width,
                         xevent->xconfigure.height);
 
-	  clutter_actor_set_size (CLUTTER_ACTOR (stage),
-				  xevent->xconfigure.width,
-				  xevent->xconfigure.height);
+          stage_x11->xwin_width = xevent->xconfigure.width;
+          stage_x11->xwin_height = xevent->xconfigure.height;
 
           /* the resize process is complete, so we can ask the stage
            * to set up the GL viewport with the new size
            */
           CLUTTER_SET_PRIVATE_FLAGS (CLUTTER_ACTOR (stage_x11->wrapper),
                                      CLUTTER_ACTOR_SYNC_MATRICES);
+
+          clutter_actor_queue_relayout (CLUTTER_ACTOR (stage_x11->wrapper));
         }
       res = FALSE;
       break;
@@ -552,12 +553,10 @@ event_translate (ClutterBackend *backend,
       break;
 
     case MapNotify:
-      clutter_stage_x11_map (stage_x11);
       res = FALSE;
       break;
 
     case UnmapNotify:
-      clutter_stage_x11_unmap (stage_x11);
       res = FALSE;
       break;
 
@@ -738,14 +737,19 @@ event_translate (ClutterBackend *backend,
         }
       else
         {  /* XInput fun.. Needs clean up. */
-#ifdef USE_XINPUT
+#ifdef HAVE_XINPUT
           int *ev_types = backend_x11->event_types;
 
           CLUTTER_NOTE (EVENT, "XInput event type: %d", xevent->type);
 
           if (xevent->type == ev_types [CLUTTER_X11_XINPUT_BUTTON_PRESS_EVENT])
             {
-              XDeviceButtonEvent *xbev = (XDeviceButtonEvent *)xevent;
+              XDeviceButtonEvent *xbev = (XDeviceButtonEvent *) xevent;
+
+              CLUTTER_NOTE (EVENT, "XINPUT Button press event for %li at %d, %d",
+                            xbev->deviceid,
+                            xbev->x,
+                            xbev->y);
 
               switch (xbev->button)
                 {
@@ -768,9 +772,9 @@ event_translate (ClutterBackend *backend,
                   event->scroll.x = xbev->x;
                   event->scroll.y = xbev->y;
                   event->scroll.modifier_state = xbev->state;
-                  event->scroll.device 
-                    = (ClutterInputDevice *)_clutter_x11_get_device_for_xid (xbev->deviceid);
+                  event->scroll.device = _clutter_x11_get_device_for_xid (xbev->deviceid);
                   break;
+
                 default:
                   event->button.type = event->type = CLUTTER_BUTTON_PRESS;
                   event->button.time = xbev->time;
@@ -778,29 +782,29 @@ event_translate (ClutterBackend *backend,
                   event->button.y = xbev->y;
                   event->button.modifier_state = xbev->state;
                   event->button.button = xbev->button;
-                  event->button.device 
-                    = (ClutterInputDevice *)_clutter_x11_get_device_for_xid (xbev->deviceid);
+                  event->button.device = _clutter_x11_get_device_for_xid (xbev->deviceid);
                   break;
                 }
 
               set_user_time (backend_x11, &xwindow, xbev->time);
-
-              CLUTTER_NOTE(EVENT, "XINPUT Button press event for %li %d %d", 
-                           xbev->deviceid, xbev->x, xbev->y);
             } 
           else if (xevent->type 
                         == ev_types[CLUTTER_X11_XINPUT_BUTTON_RELEASE_EVENT])
             {
               XDeviceButtonEvent *xbev = (XDeviceButtonEvent *)xevent;
 
+              CLUTTER_NOTE (EVENT, "XINPUT Button release event for %li at %d, %d",
+                            xbev->deviceid,
+                            xbev->x,
+                            xbev->y);
+
               /* scroll events don't have a corresponding release */
               if (xbev->button == 4 ||
                   xbev->button == 5 ||
                   xbev->button == 6 ||
                   xbev->button == 7)
                 {
-                  res = FALSE;
-                  goto out;
+                  return FALSE;
                 }
 
               event->button.type = event->type = CLUTTER_BUTTON_RELEASE;
@@ -809,27 +813,24 @@ event_translate (ClutterBackend *backend,
               event->button.y = xbev->y;
               event->button.modifier_state = xbev->state;
               event->button.button = xbev->button;
-              event->button.device 
-                    = (ClutterInputDevice *)_clutter_x11_get_device_for_xid (xbev->deviceid);
-              CLUTTER_NOTE(EVENT, "XINPUT Button release event for %li %d %d", 
-                           xbev->deviceid, xbev->x, xbev->y);
+              event->button.device = _clutter_x11_get_device_for_xid (xbev->deviceid);
             } 
           else if (xevent->type 
                        == ev_types [CLUTTER_X11_XINPUT_MOTION_NOTIFY_EVENT]) 
             {
               XDeviceMotionEvent *xmev = (XDeviceMotionEvent *)xevent;
 
+              CLUTTER_NOTE(EVENT, "XINPUT Motion event for %li at %d, %d",
+                           xmev->deviceid,
+                           xmev->x,
+                           xmev->y);
+
               event->motion.type = event->type = CLUTTER_MOTION;
               event->motion.time = xmev->time;
               event->motion.x = xmev->x;
               event->motion.y = xmev->y;
               event->motion.modifier_state = xmev->state;
-              event->motion.device 
-                    = (ClutterInputDevice *) _clutter_x11_get_device_for_xid (xmev->deviceid);
-              CLUTTER_NOTE(EVENT, "XINPUT Motion event for %li %d %d", 
-                           xmev->deviceid, 
-                           xmev->x, 
-                           xmev->y);
+              event->motion.device = _clutter_x11_get_device_for_xid (xmev->deviceid);
             } 
 #if 0
         /* the Xinput handling of key presses/releases disabled for now since
@@ -863,7 +864,7 @@ event_translate (ClutterBackend *backend,
             }
 #endif
           else 
-#endif
+#endif /* HAVE_XINPUT */
             {
               CLUTTER_NOTE (EVENT, "Uknown Event");
               res = FALSE;
@@ -871,7 +872,6 @@ event_translate (ClutterBackend *backend,
         }
     }
 
- out:  
   return res;
 }
 
@@ -884,7 +884,7 @@ events_queue (ClutterBackend *backend)
   XEvent             xevent;
   ClutterMainContext  *clutter_context;
 
-  clutter_context = clutter_context_get_default ();
+  clutter_context = _clutter_context_get_default ();
 
   while (!clutter_events_pending () && XPending (xdisplay))
     {
@@ -943,7 +943,7 @@ clutter_x11_handle_event (XEvent *xevent)
 
   clutter_threads_enter ();
 
-  clutter_context = clutter_context_get_default ();
+  clutter_context = _clutter_context_get_default ();
   backend = clutter_context->backend;
 
   event = clutter_event_new (CLUTTER_NOTHING);
